@@ -1,5 +1,5 @@
 package GD::SecurityImage::Magick;
-$GD::SecurityImage::Magick::VERSION = '1.74';
+$GD::SecurityImage::Magick::VERSION = '1.75';
 # GD method emulation class for Image::Magick
 use strict;
 use warnings;
@@ -189,22 +189,6 @@ sub setThickness { ## no critic (NamingConventions::Capitalization)
    return;
 }
 
-sub _versiongt {
-   my $self  = shift;
-   my $check = $self->_tovstr(shift);
-   my $gt    = $Image::Magick::VERSION gt $check;
-   my $eq    = $Image::Magick::VERSION eq $check;
-   my $ok    = $gt || $eq;
-   return $ok ? 1 : 0;
-}
-
-sub _versionlt {
-   my $self   = shift;
-   my $check  = $self->_tovstr(shift);
-   my $lt = $Image::Magick::VERSION lt $check ? 1 : 0;
-   return $lt;
-}
-
 sub _tovstr {
    my $self  = shift;
    my $thing = shift || return '0.0.0';
@@ -233,7 +217,7 @@ GD::SecurityImage::Magick
 
 =head1 VERSION
 
-version 1.74
+version 1.75
 
 =head1 SYNOPSIS
 
